/***************************************************************************
 *                                                                         *
 *   KNetLoad is copyright (c) 1999-2000, Markus Gustavsson                *
 *                         (c) 2002, Ben Burton                            *
 *                         (c) 2004-2005, Diego Pettenò                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef HAVE_KSNMP

#include "loadremote.h"

#ifdef HAVE_STDINT_H
# include <stdint.h>
#elif defined HAVE_SYS_TYPES_H
# include <sys/types.h>
#endif

#include <libksnmp/session1.h>

#include <kdebug.h>
#include <unistd.h>

LoadRemote::LoadRemote(QObject* parent, const QString &server, const QString &community, uint ifnum, const char* name)
	: LoadReader(parent, name), m_ifindex(ifnum)
{
	kdDebug() << "LoadRemote::LoadRemote(" << parent << ", " << server << ", " << community << ", " << ifnum << ", " << name << ")" << endl;
	m_session = new KSNMP::Session1(server, community);
	if ( ! m_session->open() )
	{
		delete m_session;
		m_session = NULL;
	}
}

LoadRemote::~LoadRemote()
{
	m_session->close();
	delete m_session;
}

bool LoadRemote::doReadingActual()
{
	kdDebug() << "LoadRemote::doReadingActual()" << endl;
	
	if ( ! m_session ) return false;
	
	QValueVector <QVariant> retvals(2);
	QStringList oids; oids << "ifInOctets." + QString::number(m_ifindex) << "ifOutOctets." + QString::number(m_ifindex);
	uint32_t status;
	
	if ( ! m_session->getVariables(oids, retvals, status) )
	{
		kdDebug() << "Unable to get ifInOctets.0 and ifOutOctets.0" << endl;
		return false;
	}
	
	currIn = retvals[0].toUInt();
	currOut = retvals[1].toUInt();
	
	return true;
}

#include "loadremote.moc"

#endif
